.. HDX Python Database documentation master file

HDX Python Database Documentation
=================================

The HDX Python Database Library provides utilities for connecting to databases in a standardised way including
through an ssh tunnel if needed.

Contents
--------

.. toctree::
   :maxdepth: 1

   source/hdx.database.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
